summaryrefslogtreecommitdiff
path: root/insanity/testrun.py
diff options
context:
space:
mode:
authorVincent Penquerc'h <vincent.penquerch@collabora.co.uk>2012-02-13 18:40:49 +0000
committerVincent Penquerc'h <vincent.penquerch@collabora.co.uk>2012-02-13 18:40:49 +0000
commit6e6edafc9b21c426f4adf94d1be08c3e3cb91b53 (patch)
tree7e7ab51f15ca879fdae3a3d8c9d3ef4b65fe26b0 /insanity/testrun.py
parenta69e302e3f1a98411e171beb0209202e36cecfa6 (diff)
First step towards external tests
Tests are now done in C, or other languages. Or will be. This is the first step towards this goal. Tests are standalone binaries, whic communicate with Insanity via D-Bus. A sample C test (which does nothing, and which is still on the quick and dirty side) is included for reference. Most of the code in this test will be made into a library so that future tests can just supply their implementation of three calls (setup, test, stop). There will be a layer above this that will take care of generic GStreamer pipeline as well.
Diffstat (limited to 'insanity/testrun.py')
-rw-r--r--insanity/testrun.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/insanity/testrun.py b/insanity/testrun.py
index 95682bc..f7dabcf 100644
--- a/insanity/testrun.py
+++ b/insanity/testrun.py
@@ -196,12 +196,12 @@ class TestRun(gobject.GObject):
self._dbusNameOwnerChangedSignal)
def _dbusNameOwnerChangedSignal(self, name, oldowner, newowner):
# we only care about connections named net.gstreamer.Insanity.RemotePythonRunner.xxx
info("name:%s , oldowner:%s, newowner:%s" % (name, oldowner, newowner))
- if not name.startswith("net.gstreamer.Insanity.RemotePythonRunner.RemotePythonRunner"):
+ if not name.startswith("net.gstreamer.Insanity.Test.Test"):
return
# extract uuid
- uuid = name.rsplit('.RemotePythonRunner', 1)[-1]
+ uuid = name.rsplit('.Test', 1)[-1]
if newowner == "":
self.emit("removed-remote-test", uuid)
elif oldowner == "":
@@ -196,12 +196,12 @@ class TestRun(gobject.GObject):
self._dbusNameOwnerChangedSignal)
def _dbusNameOwnerChangedSignal(self, name, oldowner, newowner):
- # we only care about connections named net.gstreamer.Insanity.RemotePythonRunner.xxx
+ # we only care about connections named net.gstreamer.Insanity.Test.xxx
info("name:%s , oldowner:%s, newowner:%s" % (name, oldowner, newowner))